@@ -1,13 +1,14 @@
 package Net::DNS::RR::AAAA;
-
-# $Id: AAAA.pm,v 1.2 2002/02/13 03:53:58 ctriv Exp $
-
+#
+# $Id: AAAA.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 2.100 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -107,9 +108,12 @@ Section 2.2, Para 1).
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
