@@ -1,13 +1,14 @@
 package Net::DNS::RR::DNAME;
-
-# $Id: DNAME.pm,v 1.1 2002/06/30 14:41:34 ctriv Exp $
-
+#
+# $Id: DNAME.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 2.100 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -75,9 +76,12 @@ Returns the DNAME target.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-2001 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
