@@ -1,13 +1,14 @@
 package Net::DNS::RR::MINFO;
-
-# $Id: MINFO.pm,v 1.2 2002/02/13 03:53:59 ctriv Exp $
-
+#
+# $Id: MINFO.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+#
 use strict;
-use vars qw(@ISA);
+use vars qw(@ISA $VERSION);
 
 use Net::DNS::Packet;
 
-@ISA = qw(Net::DNS::RR);
+@ISA     = qw(Net::DNS::RR);
+$VERSION = (qw$Revision: 2.100 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
@@ -58,6 +59,20 @@ sub rr_rdata {
 	return $rdata;
 }
 
+
+sub _canonicalRdata {
+	my ($self, $packet, $offset) = @_;
+	my $rdata = "";
+
+	if (exists $self->{"rmailbx"}) {
+		$rdata .= $self->_name2wire($self->{"rmailbx"});
+		$rdata .=  $self->_name2wire($self->{"emailbx"});
+	}
+
+	return $rdata;
+}
+
+
 1;
 __END__
 
@@ -89,9 +104,12 @@ Returns the RR's error mailbox field.
 
 =head1 COPYRIGHT
 
-Copyright (c) 1997-1998 Michael Fuhr.  All rights reserved.  This
-program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself. 
+Copyright (c) 1997-2002 Michael Fuhr. 
+
+Portions Copyright (c) 2002-2003 Chris Reinhardt.
+
+All rights reserved.  This program is free software; you may redistribute
+it and/or modify it under the same terms as Perl itself.
 
 =head1 SEE ALSO
 
